@@ -7,9 +7,14 @@ var Element = require('./lib/Element')
 var equal = require('./lib/equal')
 var createElement = require('./lib/createElement')
 var tag = require('./lib/tag')
+var tagString = require('./lib/tagString')
 var is = require('./lib/is')
+var clone = require('./lib/clone')
+var stringify = require('./lib/stringify')
 
-exports = module.exports = tag
+exports = module.exports = function ltx () {
+  return tag.apply(null, arguments)
+}
 
 exports.Element = Element
 
@@ -22,6 +27,7 @@ exports.isNode = is.isNode
 exports.isElement = is.isElement
 exports.isText = is.isText
 
+exports.clone = clone
 exports.createElement = createElement
 
 exports.escapeXML = escape.escapeXML
@@ -33,3 +39,6 @@ exports.Parser = Parser
 exports.parse = parse
 
 exports.tag = tag
+exports.tagString = tagString
+
+exports.stringify = stringify
